@@ -4,7 +4,7 @@
 # gli.h
 #
 # copyright (c) 2004, Carter T. Butts <buttsc@uci.edu>
-# Last Modified 11/26/04
+# Last Modified 8/24/06
 # Licensed under the GNU General Public License version 2 (June, 1991)
 #
 # Part of the R/sna package
@@ -22,6 +22,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <R.h>
+#include "utils.h"
 
 
 /*INTERNAL ROUTINES---------------------------------------------------------*/
@@ -29,6 +30,8 @@
 
 /*R-CALLABLE ROUTINES-------------------------------------------------------*/
 
+void brokerage_R(double *g, int *pn, int *cl, double *brok);
+
 void lubness_con_R(double *g, double *pn, int *r, double *viol);
 
 
